"survivalCurve" <-
function(fp,fitLine=FALSE,plotCurve=TRUE, ...) {
	fplen <- length(fp);
	fpsort <- sort(fp);
	yvals <- seq(fplen,1,by=-1)/fplen;
	if (plotCurve==T) {
	  nms <- names(list(...));
	  if ("xlab" %in% nms) {
	    monxlab = list(...)$xlab;
	  } else {
	    monxlab = "Free path";
	  }
	  if ("ylab" %in% nms) {
	    monylab = list(...)$ylab;
	  } else {
	    monylab = "log(fraction)";
	  }
	  if ("main" %in% nms) {
	    monmain = list(...)$main;
	  } else {
	    monmain = "Survival Curve";
	  }
	  plot(log(yvals)~fpsort,xlab=monxlab, main=monmain, 
	       ylab=monylab);
	}
 	if (fitLine==T) {
		fit <- lm(log(yvals)~fpsort);
		if (plotCurve==T) {
		   abline(fit$coefficients);
         	}
		return(fit);
	}
}

##########################################################
# fonction calculant le voisin le plus proche
# prend comme argument deux vecteurs x et y contenant les coordonnes des 
# individus
distMoyenneVPP = function(x, y) {
  nombre = length(x);
  distVPP = rep(0,nombre);
  for (indNr in 1:nombre) {
    indAutres = (1:nombre) != indNr
    indX = x[indNr];
    indY = y[indNr];
    dist = sqrt((x-indX)^2 + (y-indY)^2)
    distVPP[indNr] = min(dist[indAutres]);
  }
  return(mean(distVPP))
}

##########################################################
# fonction calculant le nombre de VPP du meme sexe
# prend comme argument trois vecteurs x, y et sexe contenant  
# respectivement les coordonnes et le sexe des individus
nombreVPPmemeSexe = function(x, y,sexe) {
  memeSexe = 0;
  autreSexe = 0;
  nombre = length(x);
  for (indNr in 1:nombre) {
    indAutres = (1:nombre) != indNr
    indX = x[indNr];
    indY = y[indNr];
    dist = sqrt((x-indX)^2 + (y-indY)^2)
    distVPP = min(dist[indAutres]);
    sexeVPP = sexe[distVPP==dist]
    if (sexeVPP == sexe[indNr]) {
      memeSexe = memeSexe + 1;
    } else {
      autreSexe = autreSexe + 1;
    }
  }
  return(list(meme=memeSexe, autre=autreSexe))
}


##########################################################
# fonction qui implemente le test-Q de Cochran
Cochran.Q.test <- function(x)
{
    k <- dim(x)[2]
    n <- dim(x)[1]
    g <- apply(x, 2, sum)
    l <- apply(x, 1, sum)
    Q <- ((k-1)*(k*sum(g^2)-sum(g)^2))/(k*sum(l)-sum(l^2))
    p <- pchisq(Q, k-1, lower=F)
    res <- c(Q, k-1, p)
    names(res) <- c("Statistics Q", "d.f.", "p value")
    res
}


###############################################################################
#  Test non paramétrique de comparaisons multiples avec des échantillons      #
#    de taille différentes. Nemenyi and Dunn (Zar 1999).                           #
#    A faire si Kruskal-Wallis rejette H0, pour savoir où sont les différences#
###############################################################################


Nemenyi.test=function(t,alpha=0.05)
{

 k=length(t);                   #nombre de groupes#
 tmp={};

####nombre d'évènements#   
 N=0;
 n=rep(0,k);
 for(i in 1:k)
  {
   N=N+length(t[[i]]);          
   tmp=c(tmp,t[[i]]);
   n[i]=length(t[[i]]);
  }
    
####rang moyen du groupe i#    
 a=1;
 b=0; 
 R=rep(0,k);
 for(i in 1:k)
  {
   b=b+n[i];
   R[i]=mean(rank(tmp)[a:b]);    
   a=a+n[i];
  }
    
####calcul les nombres de rangs égaux#    
 t={};                          
 tmp=sort(rank(tmp));
 c=1;
 for (i in 1:(N-1))
  {
   if (tmp[i]==tmp[i+1])
    {
     c=c+1;
    }
   else
    {
    t=c(t,c);
    c=1;
    } 
     i=i+1
  }  
 T=sum(t^3-t);
 
   
 res=matrix(NA,nrow=k,ncol=k);
 SE=matrix(data=0,nrow=k,ncol=k);
 Q=matrix(data=0,nrow=k,ncol=k);
 rang = rank(R);
 for (i in k:2)
  {
   for (j in 1:(i-1))
    {
     ii = rang[i]; jj=rang[j];
     #res[ii,jj]=FALSE;
     SE[ii,jj]=sqrt( ( N*(N+1)/12 - T/(12*(N-1)) )*(1/n[ii]+1/n[jj]) );   
     #statistique de test#
     Q[ii,jj]=abs(R[ii]-R[jj])/SE[ii,jj];  
     #si Q>Q(0.05,k) H0 rejetée#    
     if (Q[ii,jj]>-qnorm(alpha/(k*(k-1)))) {                        
      res[ii,jj]=TRUE;  
     } else {
      res[ii,jj]=FALSE;
     }
     #if (res[ii,jj]==FALSE) { break };
    }
  }
 return(list(H0="H0: mean(i)=mean(j)" , 
	 Q=Q , Qseuil=-qnorm(alpha/(k*(k-1))),
	 rankedRankSums = rang,
       interpretation="If Q[i,j]>Qseuil then reject H0: mean(i)=mean(j)"));
}
